@@ -54,6 +54,7 @@ __all__ = (
     "DatastoreStorageTypeDef",
     "DatastoreSummaryTypeDef",
     "DatastoreTypeDef",
+    "DeltaTimeSessionWindowConfigurationTypeDef",
     "DeltaTimeTypeDef",
     "DeviceRegistryEnrichActivityTypeDef",
     "DeviceShadowEnrichActivityTypeDef",
@@ -62,6 +63,8 @@ __all__ = (
     "GlueConfigurationTypeDef",
     "IotEventsDestinationConfigurationTypeDef",
     "LambdaActivityTypeDef",
+    "LateDataRuleConfigurationTypeDef",
+    "LateDataRuleTypeDef",
     "LoggingOptionsTypeDef",
     "MathActivityTypeDef",
     "OutputFileUriValueTypeDef",
@@ -168,6 +171,7 @@ ChannelSummaryTypeDef = TypedDict(
         "status": Literal["CREATING", "ACTIVE", "DELETING"],
         "creationTime": datetime,
         "lastUpdateTime": datetime,
+        "lastMessageArrivalTime": datetime,
     },
     total=False,
 )
@@ -182,6 +186,7 @@ ChannelTypeDef = TypedDict(
         "retentionPeriod": "RetentionPeriodTypeDef",
         "creationTime": datetime,
         "lastUpdateTime": datetime,
+        "lastMessageArrivalTime": datetime,
     },
     total=False,
 )
@@ -344,6 +349,7 @@ DatasetTypeDef = TypedDict(
         "lastUpdateTime": datetime,
         "retentionPeriod": "RetentionPeriodTypeDef",
         "versioningConfiguration": "VersioningConfigurationTypeDef",
+        "lateDataRules": List["LateDataRuleTypeDef"],
     },
     total=False,
 )
@@ -382,6 +388,7 @@ DatastoreSummaryTypeDef = TypedDict(
         "status": Literal["CREATING", "ACTIVE", "DELETING"],
         "creationTime": datetime,
         "lastUpdateTime": datetime,
+        "lastMessageArrivalTime": datetime,
     },
     total=False,
 )
@@ -396,10 +403,15 @@ DatastoreTypeDef = TypedDict(
         "retentionPeriod": "RetentionPeriodTypeDef",
         "creationTime": datetime,
         "lastUpdateTime": datetime,
+        "lastMessageArrivalTime": datetime,
     },
     total=False,
 )
 
+DeltaTimeSessionWindowConfigurationTypeDef = TypedDict(
+    "DeltaTimeSessionWindowConfigurationTypeDef", {"timeoutInMinutes": int}
+)
+
 DeltaTimeTypeDef = TypedDict("DeltaTimeTypeDef", {"offsetSeconds": int, "timeExpression": str})
 
 _RequiredDeviceRegistryEnrichActivityTypeDef = TypedDict(
@@ -470,6 +482,24 @@ class LambdaActivityTypeDef(_RequiredLambdaActivityTypeDef, _OptionalLambdaActiv
     pass
 
 
+LateDataRuleConfigurationTypeDef = TypedDict(
+    "LateDataRuleConfigurationTypeDef",
+    {"deltaTimeSessionWindowConfiguration": "DeltaTimeSessionWindowConfigurationTypeDef"},
+    total=False,
+)
+
+_RequiredLateDataRuleTypeDef = TypedDict(
+    "_RequiredLateDataRuleTypeDef", {"ruleConfiguration": "LateDataRuleConfigurationTypeDef"}
+)
+_OptionalLateDataRuleTypeDef = TypedDict(
+    "_OptionalLateDataRuleTypeDef", {"ruleName": str}, total=False
+)
+
+
+class LateDataRuleTypeDef(_RequiredLateDataRuleTypeDef, _OptionalLateDataRuleTypeDef):
+    pass
+
+
 LoggingOptionsTypeDef = TypedDict(
     "LoggingOptionsTypeDef", {"roleArn": str, "level": Literal["ERROR"], "enabled": bool}
 )
